package com.caimei365.user.service.impl;

import com.caimei365.user.mapper.BaseUserDao;
import com.caimei365.user.model.BaseUser;
import com.caimei365.user.model.JsonModel;
import com.caimei365.user.service.LoginService;
import com.caimei365.user.service.RedisService;
import com.caimei365.user.utils.JwtUtil;
import com.caimei365.user.utils.Md5Util;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/8
 */
@Slf4j
@Service
public class LoginServiceImpl implements LoginService {

    @Resource
    private RedisService redisService;
    @Resource
    private BaseUserDao baseUserDao;

    /**
     * 登录(用户名，密码)
     *
     * @param mobileOrEmail 手机号或邮箱
     * @param password      密码
     * @return BaseUser
     */
    @Override
    public JsonModel<BaseUser> passwordLogin(String mobileOrEmail, String password) {
        if (mobileOrEmail.isEmpty()) {
            return JsonModel.error("请填写账户名", null);
        }
        if (password.isEmpty()) {
            return JsonModel.error("请填写密码", null);
        }
        //处理比对密码
        BaseUser baseUser = baseUserDao.getBaseUserByMobileOrEmail(mobileOrEmail);
        if (baseUser != null) {
            String md5Password = Md5Util.md5(password);
            String dbPassword = baseUser.getPassword();
            if (md5Password.equals(dbPassword)) {
                if (baseUser.getUserIdentity() == 1) {
                    // 协销登录
                    return JsonModel.success(baseUser);
                } else {
                    // 返回登录校验结果
                    return logonVerify(baseUser);
                }
            }
        }
        return JsonModel.error("输入的密码和账户名不匹配", null);
    }

    /**
     * 登录校验
     * @param baseUser 用户信息
     * @return BaseUser
     */
    private JsonModel<BaseUser> logonVerify(BaseUser baseUser) {
        // 生成token给用户
        String token = JwtUtil.createToken(baseUser.getUserId());
        // 为了过期续签，将token存入redis，并设置超时时间
        redisService.set(token, token, JwtUtil.getExpireTime());
        baseUser.setToken(token);
        if (baseUser.getStatus() == 91) {
            //机构 / 供应商
            return JsonModel.error(-2, "您的企业账号已被冻结，请联系客服处理", null);
        }
        // 供应商
        if (baseUser.getUserIdentity() == 3) {
            if (baseUser.getStatus() == 3) {
                return JsonModel.error(-2, "您的企业账号正在加速审核中,审核通过后即可登录", null);
            }
            if (baseUser.getStatus() == 92) {
                return JsonModel.error(-3, "您的企业账号审核未通过", baseUser);
            }
        }
        return JsonModel.success("登录成功", baseUser);
    }
}
